@@ -36,7 +36,7 @@ from kfp.v2.components.types.artifact_types import Artifact
 #     "label-ref": "original/train/label/Sphynx_158.png",
 #     "data-type": "train"
 #   },
-    
+
     
 class DatasetMgmt(Artifact, metaclass=ABCMeta):
     def __init__(self, global_variable, log):
@@ -63,11 +63,21 @@ class DatasetMgmt(Artifact, metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def read_and_split(self, bucket_name, dataset_size, data_split):
+    def read_and_split(self, bucket_name, dataset_begin_idx, dataset_size, data_split):
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         pass
     
     @abstractmethod
     def write(self, path, dataset): 
+        self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
+        pass
+    
+    @abstractmethod
+    def read_images(self, path): 
+        self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
+        pass
+    
+    @abstractmethod
+    def augmente_image(self, image_dataset):
         self.log.info(f"{sys._getframe(0).f_code.co_name} function called")
         pass
\ No newline at end of file
